@@ -7,4 +7,4 @@ from .init import parser, subparsers
 
 from .iterdir import *
 from .fuse import *
-from .update_115_cookie import *
+from .update_115_cookies import *
